@@ -30,13 +30,6 @@ class Windows(WindowsElementsMixin, DynamicCore):
     # pylint: disable=anomalous-backslash-in-string
     """The `Windows` is a library that can be used for Windows desktop automation.
 
-    This library is at this moment in "BETA" stage as an alternative
-    library for `RPA.Desktop.Windows`. Main difference being that this
-    library is using `uiautomation`_ dependency instead of `pywinauto`.
-
-    .. _uiautomation: https://github.com/yinkaisheng/Python-UIAutomation-for-Windows
-
-
     **Installation**
 
     This library, ``RPA.Windows`` is available via **rpaframework-windows** package. This
@@ -163,8 +156,8 @@ class Windows(WindowsElementsMixin, DynamicCore):
     .. code-block:: bash
 
         id:clearButton
-        type:Group and name:'Number pad' > type:Button and index:4
-        type:Group and name:'Number pad' > control:Button index:5
+        type:Group and name:"Number pad" > type:Button and index:4
+        type:Group and name:"Number pad" > control:Button index:5
         id:Units1 > name:${unit}
         class:Button offset:370,0
 
@@ -405,11 +398,11 @@ class Windows(WindowsElementsMixin, DynamicCore):
         --------------------------------------------------------------------------------
 
         Control Window    Taskbar  # Handle: 131380
-        Click   name:'Type here to search'
+        Click   name:"Type here to search"
         Control Window    Calculator  # Handle: 3411840
-        Click   name:'Five'
-        Click   name:'Eight'
-        Click   name:'Five'
+        Click   name:Five
+        Click   name:Eight
+        Click   name:Five
 
         --------------------------------------------------------------------------------
 
@@ -438,7 +431,7 @@ class Windows(WindowsElementsMixin, DynamicCore):
             Send Keys   keys=96+4=
             ${result}=    Get Attribute    id:CalculatorResults    Name
             Log To Console    ${result}
-            ${buttons}=  Get Elements  type:Group and name:'Number pad' > type:Button
+            ${buttons}=  Get Elements  type:Group and name:"Number pad" > type:Button
             FOR  ${button}  IN  @{buttons}
                 Log To Console   ${button}
             END
@@ -460,7 +453,7 @@ class Windows(WindowsElementsMixin, DynamicCore):
                 library.send_keys(keys="96+4=")
                 result = library.get_attribute("id:CalculatorResults", "Name")
                 print(result)
-                buttons = library.get_elements("type:Group and name:'Number pad' > type:Button")
+                buttons = library.get_elements("type:Group and name:"Number pad" > type:Button")
                 for button in buttons:
                     print(button)
             finally:
